@@ -13,7 +13,7 @@ from .audio import *
 
 class WaveformEnvelope:
 
-    def __init__(self, fname, tap_function):
+    def __init__(self, fname, width, height, tap_function, ref_beats = [], prd_beats = []):
         plotargs = dict(tools="", toolbar_location=None, outline_line_color='#595959')
 
         self.fname = fname
@@ -27,9 +27,10 @@ class WaveformEnvelope:
         
         # convert to mono 
         audio =  audio.sum(axis=1) / 2
-        
         duration_secs = audio.shape[0] / srate
-        self.signal_plot = figure(plot_width=600, plot_height=350,
+        
+        
+        self.signal_plot = figure(width=width, height=height,
                                   title="Waveform Envelope",
                                   x_range=[0, duration_secs],
                                   y_range=[-1.0, 1.0],
@@ -65,6 +66,31 @@ class WaveformEnvelope:
              line_color="red", line_width=1)
         self.signal_plot.on_event(Tap, self.tap_detected)
 
+        # plot beats
+        if ref_beats: 
+            for b in ref_beats: 
+                pos = b 
+                ref_beat_source = ColumnDataSource(data=dict(
+                    xs=[[pos,pos,pos]],
+                    ys=[[0.0, 1.0, -1.0]]
+                ))
+                self.signal_plot.multi_line(xs="xs", ys="ys", source=ref_beat_source, 
+                                            line_color="blue", line_width=1)
+
+
+        if prd_beats: 
+            for b in prd_beats: 
+                pos = b 
+                prd_beat_source = ColumnDataSource(data=dict(
+                    xs=[[pos,pos,pos]],
+                    ys=[[0.0, 1.0, -1.0]]
+                ))
+                self.signal_plot.multi_line(xs="xs", ys="ys", source=prd_beat_source, 
+                                            line_color="red", line_width=1)
+                
+        
+
+
         
 
     def tap_detected(self, event):
@@ -101,11 +127,11 @@ class WaveformEnvelope:
 
 
 class Time_Waveform:
-    def __init__(self, time_range=46):
+    def __init__(self, fname, width, height, time_range=46):
         plotargs = dict(tools="", toolbar_location=None,
                         outline_line_color='#595959')
         self.signal_source = ColumnDataSource(data=dict(t=[], y=[]))
-        self.signal_plot = figure(plot_width=600, plot_height=200,
+        self.signal_plot = figure(width=width, height=height,
                                   title="Signal",
                                   x_range=[0, time_range],
                                   y_range=[-0.8, 0.8],
@@ -133,12 +159,12 @@ class Time_Waveform:
 
 
 class Spectrum:
-    def __init__(self):
+    def __init__(self, audio_filename, width, height):
         plotargs = dict(tools="", toolbar_location=None,
                         outline_line_color='#595959')
         max_freq_khz = 22050 * 0.1
         self.spectrum_source = ColumnDataSource(data=dict(f=[], y=[]))
-        self.spectrum_plot = figure(plot_width=600, plot_height=200,
+        self.spectrum_plot = figure(width=width, height=height,
                                     title="Power Spectrum",
                                     y_range=[10 ** (-4), 10 ** 3],
                                     x_range=[0, max_freq_khz],
@@ -146,6 +172,8 @@ class Spectrum:
         self.spectrum_plot.background_fill_color = "#eaeaea"
         self.spectrum_plot.line(x="f", y="y", line_color="#024768",
                                 source=self.spectrum_source)
+        self.fname = audio_filename
+        self.spectrum_plot.title.text = "PowerSpectrum - " + self.fname          
 
     def update(self, data):
         if 'spectrum' in data: 
@@ -154,6 +182,13 @@ class Spectrum:
             return 
             
         time = data['time']
+        if time is None:
+            pass
+        else:
+            self.spectrum_plot.title.text = "PowerSpectrum - " + self.fname  + '\t' + str(time)
+
+
+        
         max_freq_khz = 22050 * 0.1
         if spectrum is None:
             pass
@@ -167,7 +202,7 @@ class Spectrum:
 
 
 class CircularEq:
-    def __init__(self):
+    def __init__(self, fname, width, height):
         num_bins = 16
         eq_clamp = 20
         plotargs = dict(tools="", toolbar_location=None,
@@ -183,7 +218,7 @@ class CircularEq:
             alpha=np.tile(np.zeros_like(self.eq_range), num_bins),
         )
         self.eq_source = ColumnDataSource(data=eq_data)
-        self.eq_plot = figure(plot_width=400, plot_height=400,
+        self.eq_plot = figure(width=width, height=height,
                               x_axis_type=None, y_axis_type=None,
                               x_range=[-20, 20], y_range=[-20, 20], **plotargs)
         self.eq_plot.background_fill_color = "#eaeaea"
@@ -218,13 +253,13 @@ class CircularEq:
 
 
 class Centroid:
-    def __init__(self):
+    def __init__(self, fname, width, height):
         plotargs = dict(tools="", toolbar_location=None,
                         outline_line_color='#595959')
 
         self.centroid_source = ColumnDataSource(data=dict(t=[], y=[]))
         self.scentroid_source = ColumnDataSource(data=dict(t=[], y=[]))
-        self.centroid_plot = figure(plot_width=800, plot_height=200,
+        self.centroid_plot = figure(width=width, height=height,
                                     title="Centroid", x_range=[0, 100],
                                     y_range=[0, 200], **plotargs)
         self.centroid_plot.background_fill_color = "#eaeaea"
@@ -233,7 +268,7 @@ class Centroid:
         self.centroid_plot.line(x="t", y="y", line_color="red",
                                 source=self.scentroid_source, line_width=3)
 
-        self.scentroid_plot = figure(plot_width=800, plot_height=200,
+        self.scentroid_plot = figure(width=800, height=200,
                                      title="Smoothed Centroid (mean of previous 20 values)", x_range=[0, 100],
                                      y_range=[0, 200], **plotargs)
         self.scentroid_plot.background_fill_color = "#eaeaea"
