@@ -4,7 +4,7 @@ from threading import Thread, Event
 import sys
 
 from bokeh.io import curdoc
-from bokeh.layouts import row, column, widgetbox, gridplot
+from bokeh.layouts import row, column, gridplot
 from bokeh.models import ColumnDataSource, Slider, Div, Button, FileInput 
 from bokeh.events import Tap 
 
@@ -15,6 +15,9 @@ from .audio_widgets import WaveformEnvelope, Centroid
 from . import audio 
 import IPython.display as ipd
 import time
+import jams
+import base64
+
 
 
 audioThread_ = None 
@@ -36,18 +39,33 @@ def update():
     for k, v in audio_widgets_.items():
         v.update(audio.data)
 
-def create_audio_widgets(audio_file_name):
+def create_audio_widgets(audio_filename, width, height,
+                         ref_jams_filename, prd_jams_filename):
     """
     Create the audio widgets that will be used for
     the reactive visualizations.
     """
     
+    ref_beats = [] 
+    if (ref_jams_filename != ""): 
+        ref_beat_jam = jams.load(ref_jams_filename)
+        ref_beat_ref = ref_beat_jam.search(namespace='beat')[0]
+        ref_beats = [d.time for d in ref_beat_ref.data]
+
+    prd_beats = [] 
+    if (prd_jams_filename != ""): 
+        prd_beat_jam = jams.load(prd_jams_filename)
+        prd_beat_ref = prd_beat_jam.search(namespace='beat')[0]
+        prd_beats = [d.time for d in prd_beat_ref.data]
+
+        
+    
     audio_widgets = {} 
-    audio_widgets['spectrum'] = Spectrum()
-    audio_widgets['time_waveform'] = Time_Waveform()
-    audio_widgets['waveform_envelope'] = WaveformEnvelope(audio_file_name, waveform_click_detected)
-    audio_widgets['circulareq'] = CircularEq()
-    audio_widgets['centroid'] = Centroid() 
+    audio_widgets['spectrum'] = Spectrum(audio_filename, width, height)
+    audio_widgets['time_waveform'] = Time_Waveform(audio_filename, width, height)
+    audio_widgets['waveform_envelope'] = WaveformEnvelope(audio_filename, width, height, waveform_click_detected, ref_beats, prd_beats)
+    audio_widgets['circulareq'] = CircularEq(audio_filename, width,height)
+    audio_widgets['centroid'] = Centroid(audio_filename, width, height) 
     return audio_widgets 
 
 
@@ -63,8 +81,10 @@ def file_input_handler(attr, old, new):
     
     print('File input handler')
     print(file_input.filename)
-    global audio_file_name_ 
-    audio_file_name_  = file_input.filename
+    global audio_filename_
+
+    # decode_string = base64.b64decode(encode_string)
+    audio_filename_  = file_input.filename
     
     
 def play_handler():
@@ -83,7 +103,7 @@ def play_handler():
 
     
     if not audio_thread_started_:
-        start_audio_thread(audio_file_name_)
+        start_audio_thread(audio_filename_)
         audio_thread_started_ = True
 
     if args.playback_mode == "html":
@@ -149,17 +169,17 @@ def waveform_click_detected(event):
     audio_seek.set()
 
 
-def start_audio_thread(audio_file_name):
+def start_audio_thread(audio_filename):
     """
     Start the audio thread
     Args:
-    audio_file_name (str): the audio file from which to read the samples
+    audio_filename (str): the audio file from which to read the samples
     """
     global audio_thread_started_
     audio_thread_started_ = True 
     global audioThread_
     audioThread_ = Thread(target=audio.update_audio_data,
-                          args=(audio_file_name,
+                          args=(audio_filename,
                                 args.playback_mode,
                                 audio_play,
                                 audio_close,
@@ -171,7 +191,7 @@ def start_audio_thread(audio_file_name):
 
 audio_playing_ = False
 parser = argparse.ArgumentParser()
-parser.add_argument("audio_file_name",
+parser.add_argument("audio_filename",
                     type=str,
                     help="the audio file name"
                     )
@@ -181,6 +201,27 @@ parser.add_argument("playback_mode",
                     default='pyaudio',
                     help="The playback mode. One of ['pyaudio', 'html']"
                     )
+
+parser.add_argument("width",
+                    type=str,
+                    default="600",
+                    help="The width of the figure"
+                    )
+
+parser.add_argument("height",
+                    type=str,
+                    default="350",
+                    help="The height of the figure"
+                    )
+
+parser.add_argument("ref_jams_filename",
+                    type=str,
+                    help="the ref jams file corresponding to the audio")
+
+parser.add_argument("prd_jams_filename",
+                    type=str,
+                    help="the prd jams file corresponding to the audio")
+
 parser.add_argument("widgets",
                     nargs='+',
                     default=[],
@@ -192,17 +233,21 @@ parser.add_argument("widgets",
                     help="The audio widget names."
                     )
 args = parser.parse_args()
-audio_file_name_ = args.audio_file_name
+audio_filename_ = args.audio_filename
+ref_jams_filename_ = args.ref_jams_filename
+prd_jams_filename_ = args.prd_jams_filename
+width_ = int(args.width)
+height_ = int(args.height)
 
 # preload the audio for html playback
 if args.playback_mode == "html":
-    s = '<audio id="myaudio" src="'
-    + audio_file_name_ + '" preload="auto"></audio>'
+    s = '<audio id="myaudio" src="' + audio_filename_ + '" preload="auto"></audio>'
+    print(s)
     ipd.display(ipd.HTML(s))
 
 
 # create visualizers
-audio_widgets_ = create_audio_widgets(audio_file_name_)
+audio_widgets_ = create_audio_widgets(audio_filename_, width_, height_, ref_jams_filename_,prd_jams_filename_)
 
 # start audio thread - audio_play event controls play/pause
 audio_play = Event()
@@ -213,11 +258,11 @@ audio_seek = Event()
 control_grid = []
 # setup some sliders for controlling the widgets
 max_freq = 22050
-#freq = Slider(start=1, end=max_freq, value=max_freq, step=1, title="Frequency")
-#gain = Slider(start=1, end=20, value=1, step=1, title="Gain")
+freq = Slider(start=1, end=max_freq, value=max_freq, step=1, title="Frequency")
+gain = Slider(start=1, end=20, value=1, step=1, title="Gain")
 
-#sound_control = [gain, freq]
-#control_grid.append(sound_control)
+sound_control = [gain, freq]
+control_grid.append(sound_control)
 
 # setup playback widgets
 play_button = Button(label="Play", button_type="success")
@@ -237,15 +282,14 @@ file_input_.on_change('filename', file_input_handler)
 
 # setup the document
 filename = join(dirname(__file__), "description.html")
-desc = Div(text=open(filename).read(), render_as_text=False, width=1000)
+desc = Div(text=open(filename).read(), render_as_text=False, width=800)
 curdoc().add_root(desc)
-curdoc().add_root(gridplot(control_grid))
+
 
 # make a column of desired widgets
 plots = [audio_widgets_[x].get_plot() for x in args.widgets]
-#for p in plots: 
-#    p.on_event(Tap, waveform_click_detected)
 
 plot_column = column(plots)
 curdoc().add_root(plot_column)
 curdoc().add_root(file_input_)
+curdoc().add_root(gridplot(control_grid))
