@@ -40,8 +40,10 @@ def get_notebook_url():
     return notebook_url[:-1]
 
 
-def render(audio_input, widgets=[], playback_mode="pyaudio", notebook_url=None):
- 
+def render(audio_input, widgets=[], playback_mode="pyaudio",
+           notebook_url=None, width=600, height = 350,
+           ref_jams_file="", prd_jams_file = ""):
+
     audio_fname = audio_input
     if type(audio_input) is tuple:     # audio data input 
         audio, samplerate = audio_input
@@ -54,11 +56,12 @@ def render(audio_input, widgets=[], playback_mode="pyaudio", notebook_url=None):
 
     # set up the command line arguments passed to the application 
     argv = [audio_fname]
-    argv = argv + [playback_mode] + widgets
-
+    argv += [playback_mode]
+    argv += [str(width), str(height)] 
+    argv += [ref_jams_file, prd_jams_file]
+    argv += widgets 
 
     path_to_widgets = resource_filename(__name__, 'audio_widgets')
-    print('path_to_widgets', path_to_widgets)
     
     # create a Bokeh application from the audio_widgets directory
     handler = DirectoryHandler(filename=path_to_widgets, argv=argv)
@@ -71,36 +74,37 @@ def render(audio_input, widgets=[], playback_mode="pyaudio", notebook_url=None):
     output_notebook(resources=INLINE)
     show(app, notebook_url=notebook_url)
 
-
 # short-hand calls for specific widgets 
     
-def spectrum(audio_input, playback_mode = 'pyaudio', notebook_url=None):
+def spectrum(audio_input, playback_mode = 'pyaudio', notebook_url=None, width=600, height=350, ref_jams_file="", prd_jams_file=""):
     """ Spectrum audio widget
     """
-    render(audio_input, ['spectrum'], playback_mode, notebook_url)
+    render(audio_input, ['spectrum'], playback_mode, notebook_url, width, height, ref_jams_file, prd_jams_file)
 
 
-def time_waveform(audio_input, playback_mode = 'pyaudio', notebook_url=None):
+def time_waveform(audio_input, playback_mode = 'pyaudio', notebook_url=None, width=400, height = 400, ref_jams_file="", prd_jams_file=""):
     """ Time domain waveform 
     """
-    render(audio_input, ['time_waveform'], playback_mode, notebook_url)
+    render(audio_input, ['time_waveform'], playback_mode, notebook_url, width, height, ref_jams_file, prd_jams_file)
 
     
-def waveform_envelope(audio_input, playback_mode = 'pyaudio', notebook_url=None):
+def waveform_envelope(audio_input, playback_mode = 'pyaudio',
+                      notebook_url=None, width=800, height=300,
+                      ref_jams_file="", prd_jams_file=""):
     """ Waveform envelope 
     """
-    render(audio_input, ['waveform_envelope'], playback_mode, notebook_url)
+    render(audio_input, ['waveform_envelope'], playback_mode, notebook_url,width, height, ref_jams_file, prd_jams_file)
 
-def circulareq(audio_input, playback_mode = 'pyaudio', notebook_url=None):
+def circulareq(audio_input, playback_mode = 'pyaudio', notebook_url=None, width=300, height=300, ref_jams_file="", prd_jams_file=""):
 
     """ Circular equalizer 
     """
     
-    render(audio_input, ['circulareq'], playback_mode, notebook_url)
+    render(audio_input, ['circulareq'], playback_mode, notebook_url, width, height, ref_jams_file, prd_jams_file)
 
 
-def centroid(audio_input, playback_mode = 'pyaudio', notebook_url=None):
+def centroid(audio_input, playback_mode = 'pyaudio', notebook_url=None, width=800, height=200, ref_jams_file="", prd_jams_file=""):
     """ Spectrum audio widget
     """
-    render(audio_input, ['centroid'], playback_mode, notebook_url)
+    render(audio_input, ['centroid'], playback_mode, notebook_url, width, height, ref_jams_file, prd_jams_file)
     
